AuthEngine

Trait AuthEngine 

pub trait AuthEngine: Send + Sync {
    // Required methods
    fn begin_admin(&self) -> Result<AdminTransaction, Error>;
    fn begin_query(&self) -> Result<QueryTransaction, Error>;
    fn catalog(&self) -> Catalog;
}
Trait abstracting the engine operations needed by the authentication service.

This allows the auth crate to remain independent of the engine crate while still being able to create transactions and access the catalog.

All transactions are created with system identity — authentication operates at a privileged level.

Required Methods

Implementors